@@ -389,7 +389,10 @@ class MapCanvas(basemap.Basemap):
         self.appearance["colour_water"] = bg_color
 
         if not visible and self.map_boundary is not None:
-            self.map_boundary.remove()
+            try:
+                self.map_boundary.remove()
+            except NotImplementedError as ex:
+                logging.debug("{}".format(ex))
             self.map_boundary = None
             self.ax.figure.canvas.draw()
         elif visible:
@@ -456,13 +459,10 @@ class MapCanvas(basemap.Basemap):
         # the backgorund colour).
         if self.map_boundary is not None:
             try:
-                # TODO: review
-                # FIX (mr, 15Oct2012) -- something seems to have changed in
-                # newer Matplotlib versions: this causes an exception when
-                # the user zooms/pans..
                 self.map_boundary.remove()
             except NotImplementedError as ex:
                 logging.debug("{}".format(ex))
+            self.map_boundary = None
 
         cont_vis = self.appearance["fill_continents"]
         self.set_fillcontinents_visible(False)
